@@ -72,13 +72,15 @@ const SelectInput = ({
         ))}
       </select>
     </label>
-    {error ? (
-      <div className="error">
-        <p>Error: {error}</p>
-      </div>
-    ) : (
-      ''
-    )}
+    {error.length ? (
+        <div className="error">
+          {error.map(Error => (
+            <p>Error: {Error}</p>
+          ))}
+        </div>
+      ) : (
+        ''
+      )}
   </div>
 );
 
